summaryrefslogtreecommitdiff
path: root/lib/ansible/utils/module_docs_fragments
diff options
context:
space:
mode:
Diffstat (limited to 'lib/ansible/utils/module_docs_fragments')
-rw-r--r--lib/ansible/utils/module_docs_fragments/default_callback.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/ansible/utils/module_docs_fragments/default_callback.py b/lib/ansible/utils/module_docs_fragments/default_callback.py
index 4a343511cd..ec56a28850 100644
--- a/lib/ansible/utils/module_docs_fragments/default_callback.py
+++ b/lib/ansible/utils/module_docs_fragments/default_callback.py
@@ -28,8 +28,8 @@ class ModuleDocFragment(object):
type: boolean
version_added: '2.7'
display_failed_stderr:
- name: Use STDERR for failed tasks
- description: "Toggle to control whether failed tasks are displayed to STDERR (vs. STDOUT)"
+ name: Use STDERR for failed and unreachable tasks
+ description: "Toggle to control whether failed and unreachable tasks are displayed to STDERR (vs. STDOUT)"
default: False
env:
- name: ANSIBLE_DISPLAY_FAILED_STDERR